@@ -155,6 +155,9 @@ class EvalContext(Environment):
         self.answer: str | None = None  # Agent's submitted answer
         self.system_prompt: str | None = None  # From task.agent_config, passed to agent
 
+        # Agent config overrides from task (applied by agent when running)
+        self.append_setup_output: bool = False  # Whether to append setup tool output to prompt
+
         # Error tracking
         self.error: BaseException | None = None
 
@@ -230,13 +233,13 @@ class EvalContext(Environment):
         # using the contextvar set in __aenter__ (supports api_key passed to hud.eval())
         ctx._setup_calls = env._setup_calls.copy()
         ctx._evaluate_calls = env._evaluate_calls.copy()
+        ctx._integration_test_calls = getattr(env, "_integration_test_calls", []).copy()
+        ctx._setup_results = getattr(env, "_setup_results", []).copy()
 
         # Copy scenarios (definitions) by reference - they don't change
         ctx._scenarios = getattr(env, "_scenarios", {})
         # Create fresh session state for this eval (parallel evals each need their own)
-        ctx._scenario_sessions = {}
-        ctx._scenario_latest = {}
-        ctx._scenario_answers = {}
+        ctx._active_session = None
 
         # Store source env name for remote scenario lookups
         ctx._source_env_name = env.name
@@ -302,10 +305,20 @@ class EvalContext(Environment):
             code_snippet: Code being evaluated
             trace: Whether to send traces to backend
             quiet: Whether to suppress output
+
+        Raises:
+            ValueError: If task.args is None (template tasks cannot be run directly)
         """
         from hud.environment import Environment
         from hud.eval.task import build_eval_name
 
+        # Validate that task has args (not a template)
+        if task.args is None:
+            raise ValueError(
+                f"Cannot run task with args=None (this is a template). "
+                f"Provide args when creating the task: env('{task.scenario}', **args)"
+            )
+
         eval_name = name or build_eval_name(task.scenario, task.args)
 
         # task.env is guaranteed to be Environment after Task.__post_init__
@@ -328,13 +341,26 @@ class EvalContext(Environment):
         # Store task info for scenario execution
         ctx._task = task
 
-        # Set system_prompt from task.agent_config
+        # Copy agent_config fields from task to ctx (these override agent defaults)
         if task.agent_config:
-            if isinstance(task.agent_config, dict):
-                if task.agent_config.get("system_prompt"):
-                    ctx.system_prompt = task.agent_config["system_prompt"]
-            elif task.agent_config.system_prompt:
-                ctx.system_prompt = task.agent_config.system_prompt
+            agent_config = task.agent_config
+            if isinstance(agent_config, dict):
+                if agent_config.get("system_prompt"):
+                    ctx.system_prompt = agent_config["system_prompt"]
+                if agent_config.get("append_setup_output"):
+                    ctx.append_setup_output = agent_config["append_setup_output"]
+                # Also check append_setup_tool alias
+                if agent_config.get("append_setup_tool"):
+                    ctx.append_setup_output = agent_config["append_setup_tool"]
+            else:
+                # It's a BaseAgentConfig or TaskAgentConfig object
+                if getattr(agent_config, "system_prompt", None):
+                    ctx.system_prompt = agent_config.system_prompt
+                if getattr(agent_config, "append_setup_output", False):
+                    ctx.append_setup_output = agent_config.append_setup_output
+                # Also check append_setup_tool alias
+                if getattr(agent_config, "append_setup_tool", False):
+                    ctx.append_setup_output = True
 
         return ctx
 
@@ -343,7 +369,7 @@ class EvalContext(Environment):
         if self._task is None or self._task.scenario is None:
             return
 
-        prompt = await self.run_scenario_setup(self._task.scenario, self._task.args)
+        prompt = await self.run_scenario_setup(self._task.scenario, self._task.args or {})
         if prompt:
             self.prompt = prompt
 
@@ -417,6 +443,33 @@ class EvalContext(Environment):
         """True if a scenario is running and can accept submissions."""
         return self._task is not None and self._task.scenario is not None
 
+    @property
+    def setup_output(self) -> str | None:
+        """Get setup tool output as formatted string for prepending to agent context.
+
+        Returns None if no setup tools were executed or all results were empty.
+        Used by agents when append_setup_output is enabled.
+        """
+        import mcp.types as mcp_types
+
+        setup_results = getattr(self, "_setup_results", [])
+        if not setup_results:
+            return None
+
+        output_parts: list[str] = []
+        for result in setup_results:
+            if result.content:
+                output_parts.extend(
+                    block.text
+                    for block in result.content
+                    if isinstance(block, mcp_types.TextContent)
+                )
+
+        if not output_parts:
+            return None
+
+        return "\n".join(output_parts)
+
     # =========================================================================
     # Backend Integration
     # =========================================================================
